@@ -13,18 +13,20 @@ __version__ = importlib_metadata.version(__name__)
 
 from . import utilities
 from .utilities import (
-    file_format, sxs_directory, read_config, write_config, sxs_id, lev_number,
+    file_format, sxs_directory, read_config, write_config,
+    sxs_id, lev_number, sxs_id_to_url,
     jit, vectorize, guvectorize, version_info
 )
 from .time_series import TimeSeries
 from .metadata import Metadata
 from .catalog import Catalog
 from .horizons import Horizons, HorizonQuantities
-from .waveforms import WaveformModes #, WaveformGrid, WaveformSignal
+from .waveforms import WaveformModes, WaveformModesDict, to_lvc_conventions #, WaveformGrid, WaveformSignal
 from .waveforms import rotating_paired_xor_multishuffle_bzip2 as rpxmb
 from .waveforms import rotating_paired_diff_multishuffle_bzip2 as rpdmb
+from .waveforms import spectre_cce_v1
 from . import catalog, metadata, horizons, waveforms, zenodo, caltechdata
-from .handlers import load, loadcontext
+from .handlers import load, loadcontext, load_lvc
 
 # The speed of light is, of course, defined to be exactly
 speed_of_light = 299_792_458.0  # m/s
@@ -48,3 +50,7 @@ solar_mass_parameter = 1.32712440041e20  # m^3/s^2
 # precision than is warranted by the measurement.
 m_sun_in_meters = 1476.6250385063112526099633973363  # m
 m_sun_in_seconds = 4.925490949162941425997992909269e-06  # s
+
+
+doi_prefix = "10.26138"
+doi_url = f"https://doi.org/{doi_prefix}/"
