@@ -1,4 +1,3 @@
-import sxs
 import numpy as np
 
 from scipy.integrate import trapezoid
@@ -7,6 +6,7 @@ import multiprocessing as mp
 from functools import partial
 
 
+
 def align1d(wa, wb, t1, t2, n_brute_force=None):
     """Align waveforms by shifting in time
 
@@ -208,6 +208,7 @@ def align2d(wa, wb, t1, t2, n_brute_force_δt=None, n_brute_force_δϕ=5, includ
     """
     from scipy.interpolate import CubicSpline
     from scipy.optimize import least_squares
+    from .. import WaveformModes
 
     wa_orig = wa
     wa = wa.copy()
@@ -262,7 +263,7 @@ def align2d(wa, wb, t1, t2, n_brute_force_δt=None, n_brute_force_δϕ=5, includ
 
     normalization = trapezoid(
         CubicSpline(
-            wb.t, wb[:, wb.index(2, -2) : wb.index(ell_max + 1, -(ell_max + 1))].norm
+            wb.t, wb[:, wb.index(2, -2) : wb.index(ell_max + 1, -(ell_max + 1))].norm ** 2
         )(t_reference),
         t_reference,
     )
@@ -292,7 +293,7 @@ def align2d(wa, wb, t1, t2, n_brute_force_δt=None, n_brute_force_δϕ=5, includ
         optimums.append(optimum)
         δt, δϕ = optimum.x
 
-        wa_prime = sxs.WaveformModes(
+        wa_prime = WaveformModes(
             input_array=(
                 wa_orig[:, wa_orig.index(2, -2) : wa_orig.index(ell_max + 1, -(ell_max + 1))].data
                 * np.exp(1j * m * δϕ)
